FirebaseApi class

Constructors

FirebaseApi(String path, {FirebaseFirestore? firestore})

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → String
final
ref ↔ CollectionReference<Object?>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addDocument({String? id, required Map<String, dynamic> data}) → Future<DocumentReference<Object?>>
batch() → WriteBatch
getDataCollection() → Future<QuerySnapshot<Object?>>
getDocumentById(String id) → Future<DocumentSnapshot<Object?>>
getDocumentRef({String? id}) → DocumentReference<Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeDocument(String id) → Future<void>
streamDataCollection() → Stream<QuerySnapshot<Object?>>
toString() → String
A string representation of this object.
inherited
updateDocument({String? id, required Map<String, dynamic> data}) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited