NSFirebase class

NSFirebase class This class is used to initialize firebase

Constructors

NSFirebase()

Properties

buildNumber → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
isInitialized → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
no setter

Methods

init({required bool printLogs, required String buildNumber, required String version, LogCallBack? appLogsFunction, ErrorLogCallBack? errorLogsFunction, FirebaseOptions? options, String? name}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ NSFirebase
getter/setter pair