CustomException class

Implemented types

Constructors

CustomException({required String code, String? message, dynamic details})

Properties

code → String
An error code.
final
details → dynamic
Error details, possibly null.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
A human-readable error message, possibly null.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited